==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/ExtendedLocationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.ExtendedLocationArgs.builder
import com.pulumi.azurenative.recoveryservices.kotlin.enums.ExtendedLocationType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Extended location of the resource.
 * @property name The name of the extended location.
 * @property type The extended location type.
 */
public data class ExtendedLocationArgs(
    public val name: Output<String>,
    public val type: Output<Either<String, ExtendedLocationType>>,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.ExtendedLocationArgs> {
    override fun toJava(): com.pulumi.azurenative.recoveryservices.inputs.ExtendedLocationArgs =
        com.pulumi.azurenative.recoveryservices.inputs.ExtendedLocationArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .type(
                type.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ExtendedLocationArgs].
 */
@PulumiTagMarker
public class ExtendedLocationArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var type: Output<Either<String, ExtendedLocationType>>? = null

    /**
     * @param value The name of the extended location.
     */
    @JvmName("ototitljtlcwbnpm")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The extended location type.
     */
    @JvmName("exsnnfhsuoxidhkq")
    public suspend fun type(`value`: Output<Either<String, ExtendedLocationType>>) {
        this.type = value
    }

    /**
     * @param value The name of the extended location.
     */
    @JvmName("xmnmbgevedffjdlv")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The extended location type.
     */
    @JvmName("ueprtkbofqxopeey")
    public suspend fun type(`value`: Either<String, ExtendedLocationType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The extended location type.
     */
    @JvmName("stpkdtptocdfoksv")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ExtendedLocationType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The extended location type.
     */
    @JvmName("bewmhkohxtaiekgx")
    public fun type(`value`: ExtendedLocationType) {
        val toBeMapped = Either.ofRight<String, ExtendedLocationType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ExtendedLocationArgs = ExtendedLocationArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/ExtendedLocationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.ExtendedLocationArgs.builder
import com.pulumi.azurenative.recoveryservices.kotlin.enums.ExtendedLocationType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Extended location of the resource.
 * @property name The name of the extended location.
 * @property type The extended location type.
 */
public data class ExtendedLocationArgs(
    public val name: Output<String>,
    public val type: Output<Either<String, ExtendedLocationType>>,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.ExtendedLocationArgs> {
    override fun toJava(): com.pulumi.azurenative.recoveryservices.inputs.ExtendedLocationArgs =
        com.pulumi.azurenative.recoveryservices.inputs.ExtendedLocationArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .type(
                type.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ExtendedLocationArgs].
 */
@PulumiTagMarker
public class ExtendedLocationArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var type: Output<Either<String, ExtendedLocationType>>? = null

    /**
     * @param value The name of the extended location.
     */
    @JvmName("ymcabsanphvjttoa")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The extended location type.
     */
    @JvmName("mrwndlshrtrcxejb")
    public suspend fun type(`value`: Output<Either<String, ExtendedLocationType>>) {
        this.type = value
    }

    /**
     * @param value The name of the extended location.
     */
    @JvmName("micwerpjwhctypbv")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The extended location type.
     */
    @JvmName("juxogmaoajchtxfq")
    public suspend fun type(`value`: Either<String, ExtendedLocationType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The extended location type.
     */
    @JvmName("vuuuujtsdyksyhkh")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ExtendedLocationType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The extended location type.
     */
    @JvmName("lyuudvfytjdxonoq")
    public fun type(`value`: ExtendedLocationType) {
        val toBeMapped = Either.ofRight<String, ExtendedLocationType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ExtendedLocationArgs = ExtendedLocationArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
